Module storage

Module storage 

Contains the StorageBackend trait that is by the Server and its various implementations.

Structs

Fileinfo
Fileinfo contains the path and Metadata of a file.
Filesystem
StorageBackend that uses a local filesystem, like a traditional FTP server.

Enums

Error
The Error variants that can be produced by the StorageBackend implementations.

Traits

Metadata
Represents the Metadata of a file
StorageBackend
The Storage trait defines a common interface to different storage backends for our FTP Server, e.g. for a Filesystem or GCP buckets.